@@ -27,7 +27,7 @@ class Expression:
     def __init__(self, **args):
         self.key = self.__class__.__name__.lower()
         self.args = args
-        self._set_parent(**args)
+        self._set_parent(args)
         self.parent = None
         self.arg_key = None
 
@@ -90,9 +90,9 @@ class Expression:
             value: value to set the arg to.
         """
         self.args[arg] = value
-        self._set_parent(**{arg: value})
+        self._set_parent({arg: value})
 
-    def _set_parent(self, **kwargs):
+    def _set_parent(self, kwargs):
         for arg_key, node in kwargs.items():
             for v in ensure_list(node):
                 if isinstance(v, Expression):
@@ -1659,6 +1659,10 @@ class ArraySize(Func):
     pass
 
 
+class ArraySort(Func):
+    arg_types = {"this": True, "expression": False}
+
+
 class Avg(AggFunc):
     pass
 
@@ -1821,6 +1825,10 @@ class SetAgg(AggFunc):
     pass
 
 
+class SortArray(Func):
+    arg_types = {"this": True, "asc": False}
+
+
 class Split(Func):
     arg_types = {"this": True, "expression": True}
 
@@ -2359,6 +2367,23 @@ def column(col, table=None, quoted=None):
     )
 
 
+def table_(table, db=None, catalog=None, quoted=None):
+    """
+    Build a Table.
+    Args:
+        table (str or Expression): column name
+        db (str or Expression): db name
+        catalog (str or Expression): catalog name
+    Returns:
+        Table: table instance
+    """
+    return Table(
+        this=to_identifier(table, quoted=quoted),
+        db=to_identifier(db, quoted=quoted),
+        catalog=to_identifier(catalog, quoted=quoted),
+    )
+
+
 def replace_children(expression, fun):
     """
     Replace children of an expression with the result of a lambda fun(child) -> exp.
@@ -2373,10 +2398,11 @@ def replace_children(expression, fun):
             if isinstance(cn, Expression):
                 cns = ensure_list(fun(cn))
                 for child_node in cns:
+                    new_child_nodes.append(child_node)
                     child_node.parent = expression
+                    child_node.arg_key = k
             else:
-                cns = [cn]
-            new_child_nodes.extend(cns)
+                new_child_nodes.append(cn)
 
         expression.args[k] = new_child_nodes if is_list_arg else new_child_nodes[0]
 
